======================
Manipulation/selection
======================

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Expr.append
    Expr.arg_sort
    Expr.arg_true
    Expr.backward_fill
    Expr.bottom_k
    Expr.bottom_k_by
    Expr.cast
    Expr.ceil
    Expr.clip
    Expr.cut
    Expr.drop_nans
    Expr.drop_nulls
    Expr.explode
    Expr.extend_constant
    Expr.fill_nan
    Expr.fill_null
    Expr.filter
    Expr.flatten
    Expr.floor
    Expr.forward_fill
    Expr.gather
    Expr.gather_every
    Expr.get
    Expr.head
    Expr.inspect
    Expr.interpolate
    Expr.interpolate_by
    Expr.limit
    Expr.lower_bound
    Expr.pipe
    Expr.qcut
    Expr.rechunk
    Expr.reinterpret
    Expr.repeat_by
    Expr.replace
    Expr.replace_strict
    Expr.reshape
    Expr.reverse
    Expr.rle
    Expr.rle_id
    Expr.round
    Expr.round_sig_figs
    Expr.sample
    Expr.shift
    Expr.shrink_dtype
    Expr.shuffle
    Expr.slice
    Expr.sort
    Expr.sort_by
    Expr.tail
    Expr.to_physical
    Expr.top_k
    Expr.top_k_by
    Expr.upper_bound
    Expr.where
